@@ -31,7 +31,6 @@ class AsyncBaseReader:
 
         self.max_token_num = 4096
         self.encoding = tiktoken.get_encoding("gpt2")
-
         self.token_usage = 0
 
     async def _summary_with_chat(self, paper_list: list[Paper], key_words):
@@ -45,7 +44,7 @@ class AsyncBaseReader:
     def summary_with_chat(self, paper_list: list[Paper], key_words):
         asyncio.run(self._summary_with_chat(paper_list, key_words))
 
-    def find_title(self, text):
+    def update_title(self, text):
         for line in text.split("\n"):
             if "Title:" in line:
                 return line.split("Title:")[1].strip()
@@ -54,7 +53,6 @@ class AsyncBaseReader:
         self, paper: Paper, paper_index: int, key_words
     ):
         htmls = []
-        # 第一步先用title，abs，和introduction进行总结。
         text = ""
         text += "Title:" + paper.title
         text += "Url:" + paper.url
@@ -84,8 +82,11 @@ class AsyncBaseReader:
             else:
                 raise e
 
-        # if (title := self.find_title(chat_summary_text)) is not None:
-        #     paper.title = title
+        if (
+            paper.title == ""
+            and (title := self.update_title(chat_summary_text)) is not None
+        ):
+            paper.title = title
 
         htmls.append("## Paper:" + str(paper_index + 1))
         htmls.append("\n\n\n")
