@@ -8,7 +8,6 @@ from PIL import Image
 
 class Paper:
     def __init__(self, path, title="", url="", abs="", authers=[]):
-        # 初始化函数，根据pdf路径初始化Paper对象
         self.url = url  # 文章链接
         self.path = path  # pdf路径
         self.section_names = []  # 段落标题
@@ -34,6 +33,7 @@ class Paper:
             "IX",
             "X",
         ]
+
         self.digit_num = [str(d + 1) for d in range(10)]
         self.first_image = ""
 
@@ -69,39 +69,33 @@ class Paper:
         :param image_path: 图片提取后的保存路径
         :return:
         """
-        # open file
         max_size = 0
         image_list = []
+        ext = None
         with fitz.Document(self.path) as my_pdf_file:
-            # 遍历所有页面
             for page_number in range(1, len(my_pdf_file) + 1):
-                # 查看独立页面
                 page = my_pdf_file[page_number - 1]
-                # 查看当前页所有图片
                 page.get_images()
-                # 遍历当前页面所有图片
-                for image_number, image in enumerate(page.get_images(), start=1):
-                    # 访问图片xref
+                for _, image in enumerate(page.get_images(), start=1):
                     xref_value = image[0]
-                    # 提取图片信息
                     base_image = my_pdf_file.extract_image(xref_value)
-                    # 访问图片
                     image_bytes = base_image["image"]
-                    # 获取图片扩展名
                     ext = base_image["ext"]
-                    # 加载图片
                     image = Image.open(io.BytesIO(image_bytes))
                     image_size = image.size[0] * image.size[1]
                     if image_size > max_size:
                         max_size = image_size
                     image_list.append(image)
 
+        if ext is None:
+            raise Exception("No image found in pdf")
+
         for image in image_list:
             image_size = image.size[0] * image.size[1]
             if image_size == max_size:
                 image_name = f"image.{ext}"
                 im_path = os.path.join(image_path, image_name)
-                logger.info(f"image_path: {im_path}")
+                logger.trace(f"image_path: {im_path}")
 
                 max_pix = 480
                 min(image.size[0], image.size[1])
@@ -118,11 +112,9 @@ class Paper:
                 return im_path, ext
         return None, None
 
-    # 定义一个函数，根据字体的大小，识别每个章节名称，并返回一个列表
     def get_chapter_names(
         self,
     ):
-        # # 打开一个pdf文件
         doc = fitz.open(self.path)  # pdf文档
         text_list = [page.get_text() for page in doc]
         all_text = ""
@@ -149,11 +141,14 @@ class Paper:
 
         return chapter_names
 
+    def fetch_title(self):
+        logger.trace(self.pdf.metadata)
+        return self.pdf.metadata["title"]
+
     def get_title(self):
-        doc = self.pdf  # 打开pdf文件
         max_font_size = 0  # 初始化最大字体大小为0
         max_font_sizes = [0]
-        for page_index, page in enumerate(doc):  # 遍历每一页
+        for page_index, page in enumerate(self.pdf):  # 遍历每一页
             text = page.get_text("dict")  # 获取页面上的文本信息
             blocks = text["blocks"]  # 获取文本块列表
             for block in blocks:  # 遍历每个文本块
@@ -169,7 +164,8 @@ class Paper:
         max_font_sizes.sort()
         logger.trace(f"max_font_sizes {max_font_sizes[-10:]}")
         cur_title = ""
-        for page_index, page in enumerate(doc):  # 遍历每一页
+
+        for page_index, page in enumerate(self.pdf):  # 遍历每一页
             text = page.get_text("dict")  # 获取页面上的文本信息
             blocks = text["blocks"]  # 获取文本块列表
             for block in blocks:  # 遍历每个文本块
@@ -195,12 +191,12 @@ class Paper:
                                 else:
                                     cur_title += " " + cur_string
                             self.title_page = page_index
-                            # break
+
         title = cur_title.replace("\n", " ")
         return title
 
     def _get_all_page_index(self):
-        # 定义需要寻找的章节名称列表
+        # define the chapter name list
         section_list = [
             "Abstract",
             "Introduction",
@@ -216,7 +212,6 @@ class Paper:
             "Method",
             "Approach",
             "Approaches",
-            # exp
             "Materials and Methods",
             "Experiment Settings",
             "Experiment",
@@ -231,40 +226,32 @@ class Paper:
             "Conclusion",
             "References",
         ]
-        # 初始化一个字典来存储找到的章节和它们在文档中出现的页码
         section_page_dict = {}
-        # 遍历每一页文档
         for page_index, page in enumerate(self.pdf):
-            # 获取当前页面的文本内容
             cur_text = page.get_text()
-            # 遍历需要寻找的章节名称列表
             for section_name in section_list:
-                # 将章节名称转换成大写形式
                 section_name_upper = section_name.upper()
-                # 如果当前页面包含"Abstract"这个关键词
                 if "Abstract" == section_name and section_name in cur_text:
-                    # 将"Abstract"和它所在的页码加入字典中
                     section_page_dict[section_name] = page_index
-                # 如果当前页面包含章节名称，则将章节名称和它所在的页码加入字典中
                 else:
                     if section_name + "\n" in cur_text:
                         section_page_dict[section_name] = page_index
                     elif section_name_upper + "\n" in cur_text:
                         section_page_dict[section_name] = page_index
-        # 返回所有找到的章节名称及它们在文档中出现的页码
         return section_page_dict
 
     def _get_all_page(self):
         """
-        获取PDF文件中每个页面的文本信息，并将文本信息按照章节组织成字典返回。
+
+        Get the text information of each page in the PDF file and return the text information as a dictionary according to the chapter.
 
         Returns:
-            section_dict (dict): 每个章节的文本信息字典，key为章节名，value为章节文本。
+            section_dict (dict): Text information dictionary for each chapter, key for chapter name, value for chapter text.
+
         """
         text_list = []
         section_dict = {}
 
-        # 再处理其他章节：
         text_list = [page.get_text() for page in self.pdf]
         for sec_index, sec_name in enumerate(self.section_page_dict):
             logger.trace(
@@ -273,7 +260,6 @@ class Paper:
             if sec_index <= 0 and self.abs:
                 continue
             else:
-                # 直接考虑后面的内容：
                 start_page = self.section_page_dict[sec_name]
                 if sec_index < len(list(self.section_page_dict.keys())) - 1:
                     end_page = self.section_page_dict[
@@ -281,7 +267,9 @@ class Paper:
                     ]
                 else:
                     end_page = len(text_list)
+
                 logger.trace(f"{start_page=}, {end_page=}")
+
                 cur_sec_text = ""
                 if end_page - start_page == 0:
                     if sec_index < len(list(self.section_page_dict.keys())) - 1:
